##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`tools.ozone.hosting.getAccountHistory`."""

    did: string_formats.Did  #: Did.
    cursor: t.Optional[str] = None  #: Cursor.
    events: t.Optional[
        t.List[
            t.Union[
                t.Literal['accountCreated'],
                t.Literal['emailUpdated'],
                t.Literal['emailConfirmed'],
                t.Literal['passwordUpdated'],
                t.Literal['handleUpdated'],
                str,
            ]
        ]
    ] = None  #: Events.
    limit: te.Annotated[t.Optional[int], Field(ge=1, le=100)] = None  #: Limit.


class ParamsDict(t.TypedDict):
    did: string_formats.Did  #: Did.
    cursor: te.NotRequired[t.Optional[str]]  #: Cursor.
    events: te.NotRequired[
        t.Optional[
            t.List[
                t.Union[
                    t.Literal['accountCreated'],
                    t.Literal['emailUpdated'],
                    t.Literal['emailConfirmed'],
                    t.Literal['passwordUpdated'],
                    t.Literal['handleUpdated'],
                    str,
                ]
            ]
        ]
    ]  #: Events.
    limit: te.NotRequired[t.Optional[int]]  #: Limit.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`tools.ozone.hosting.getAccountHistory`."""

    events: t.List['models.ToolsOzoneHostingGetAccountHistory.Event']  #: Events.
    cursor: t.Optional[str] = None  #: Cursor.


class Event(base.ModelBase):
    """Definition model for :obj:`tools.ozone.hosting.getAccountHistory`."""

    created_at: string_formats.DateTime  #: Created at.
    created_by: str  #: Created by.
    details: te.Annotated[
        t.Union[
            'models.ToolsOzoneHostingGetAccountHistory.AccountCreated',
            'models.ToolsOzoneHostingGetAccountHistory.EmailUpdated',
            'models.ToolsOzoneHostingGetAccountHistory.EmailConfirmed',
            'models.ToolsOzoneHostingGetAccountHistory.PasswordUpdated',
            'models.ToolsOzoneHostingGetAccountHistory.HandleUpdated',
        ],
        Field(discriminator='py_type'),
    ]  #: Details.

    py_type: t.Literal['tools.ozone.hosting.getAccountHistory#event'] = Field(
        default='tools.ozone.hosting.getAccountHistory#event', alias='$type', frozen=True
    )


class AccountCreated(base.ModelBase):
    """Definition model for :obj:`tools.ozone.hosting.getAccountHistory`."""

    email: t.Optional[str] = None  #: Email.
    handle: t.Optional[string_formats.Handle] = None  #: Handle.

    py_type: t.Literal['tools.ozone.hosting.getAccountHistory#accountCreated'] = Field(
        default='tools.ozone.hosting.getAccountHistory#accountCreated', alias='$type', frozen=True
    )


class EmailUpdated(base.ModelBase):
    """Definition model for :obj:`tools.ozone.hosting.getAccountHistory`."""

    email: str  #: Email.

    py_type: t.Literal['tools.ozone.hosting.getAccountHistory#emailUpdated'] = Field(
        default='tools.ozone.hosting.getAccountHistory#emailUpdated', alias='$type', frozen=True
    )


class EmailConfirmed(base.ModelBase):
    """Definition model for :obj:`tools.ozone.hosting.getAccountHistory`."""

    email: str  #: Email.

    py_type: t.Literal['tools.ozone.hosting.getAccountHistory#emailConfirmed'] = Field(
        default='tools.ozone.hosting.getAccountHistory#emailConfirmed', alias='$type', frozen=True
    )


class PasswordUpdated(base.ModelBase):
    """Definition model for :obj:`tools.ozone.hosting.getAccountHistory`."""

    py_type: t.Literal['tools.ozone.hosting.getAccountHistory#passwordUpdated'] = Field(
        default='tools.ozone.hosting.getAccountHistory#passwordUpdated', alias='$type', frozen=True
    )


class HandleUpdated(base.ModelBase):
    """Definition model for :obj:`tools.ozone.hosting.getAccountHistory`."""

    handle: string_formats.Handle  #: Handle.

    py_type: t.Literal['tools.ozone.hosting.getAccountHistory#handleUpdated'] = Field(
        default='tools.ozone.hosting.getAccountHistory#handleUpdated', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Main(base.ModelBase):
    """Definition model for :obj:`app.bsky.richtext.facet`. Annotation of a sub-string within rich text."""

    features: t.List[
        te.Annotated[
            t.Union[
                'models.AppBskyRichtextFacet.Mention',
                'models.AppBskyRichtextFacet.Link',
                'models.AppBskyRichtextFacet.Tag',
            ],
            Field(discriminator='py_type'),
        ]
    ]  #: Features.
    index: 'models.AppBskyRichtextFacet.ByteSlice'  #: Index.

    py_type: t.Literal['app.bsky.richtext.facet'] = Field(default='app.bsky.richtext.facet', alias='$type', frozen=True)


class Mention(base.ModelBase):
    """Definition model for :obj:`app.bsky.richtext.facet`. Facet feature for mention of another account. The text is usually a handle, including a '@' prefix, but the facet reference is a DID."""

    did: string_formats.Did  #: Did.

    py_type: t.Literal['app.bsky.richtext.facet#mention'] = Field(
        default='app.bsky.richtext.facet#mention', alias='$type', frozen=True
    )


class Link(base.ModelBase):
    """Definition model for :obj:`app.bsky.richtext.facet`. Facet feature for a URL. The text URL may have been simplified or truncated, but the facet reference should be a complete URL."""

    uri: string_formats.Uri  #: Uri.

    py_type: t.Literal['app.bsky.richtext.facet#link'] = Field(
        default='app.bsky.richtext.facet#link', alias='$type', frozen=True
    )


class Tag(base.ModelBase):
    """Definition model for :obj:`app.bsky.richtext.facet`. Facet feature for a hashtag. The text usually includes a '#' prefix, but the facet reference should not (except in the case of 'double hash tags')."""

    tag: str = Field(max_length=640)  #: Tag.

    py_type: t.Literal['app.bsky.richtext.facet#tag'] = Field(
        default='app.bsky.richtext.facet#tag', alias='$type', frozen=True
    )


class ByteSlice(base.ModelBase):
    """Definition model for :obj:`app.bsky.richtext.facet`. Specifies the sub-string range a facet feature applies to. Start index is inclusive, end index is exclusive. Indices are zero-indexed, counting bytes of the UTF-8 encoded text. NOTE: some languages, like Javascript, use UTF-16 or Unicode codepoints for string slice indexing; in these languages, convert to byte arrays before working with facets."""

    byte_end: int = Field(ge=0)  #: Byte end.
    byte_start: int = Field(ge=0)  #: Byte start.

    py_type: t.Literal['app.bsky.richtext.facet#byteSlice'] = Field(
        default='app.bsky.richtext.facet#byteSlice', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`app.bsky.feed.getQuotes`."""

    uri: string_formats.AtUri  #: Reference (AT-URI) of post record.
    cid: t.Optional[string_formats.Cid] = (
        None  #: If supplied, filters to quotes of specific version (by CID) of the post record.
    )
    cursor: t.Optional[str] = None  #: Cursor.
    limit: te.Annotated[t.Optional[int], Field(ge=1, le=100)] = None  #: Limit.


class ParamsDict(t.TypedDict):
    uri: string_formats.AtUri  #: Reference (AT-URI) of post record.
    cid: te.NotRequired[
        t.Optional[string_formats.Cid]
    ]  #: If supplied, filters to quotes of specific version (by CID) of the post record.
    cursor: te.NotRequired[t.Optional[str]]  #: Cursor.
    limit: te.NotRequired[t.Optional[int]]  #: Limit.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`app.bsky.feed.getQuotes`."""

    posts: t.List['models.AppBskyFeedDefs.PostView']  #: Posts.
    uri: string_formats.AtUri  #: Uri.
    cid: t.Optional[string_formats.Cid] = None  #: Cid.
    cursor: t.Optional[str] = None  #: Cursor.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`app.bsky.unspecced.getPostThreadOtherV2`."""

    anchor: string_formats.AtUri  #: Reference (AT-URI) to post record. This is the anchor post.
    prioritize_followed_users: t.Optional[bool] = (
        False  #: Whether to prioritize posts from followed users. It only has effect when the user is authenticated.
    )


class ParamsDict(t.TypedDict):
    anchor: string_formats.AtUri  #: Reference (AT-URI) to post record. This is the anchor post.
    prioritize_followed_users: te.NotRequired[
        t.Optional[bool]
    ]  #: Whether to prioritize posts from followed users. It only has effect when the user is authenticated.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`app.bsky.unspecced.getPostThreadOtherV2`."""

    thread: t.List[
        'models.AppBskyUnspeccedGetPostThreadOtherV2.ThreadItem'
    ]  #: A flat list of other thread items. The depth of each item is indicated by the depth property inside the item.


class ThreadItem(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.getPostThreadOtherV2`."""

    depth: int  #: The nesting level of this item in the thread. Depth 0 means the anchor item. Items above have negative depths, items below have positive depths.
    uri: string_formats.AtUri  #: Uri.
    value: te.Annotated[
        t.Union['models.AppBskyUnspeccedDefs.ThreadItemPost'], Field(discriminator='py_type')
    ]  #: Value.

    py_type: t.Literal['app.bsky.unspecced.getPostThreadOtherV2#threadItem'] = Field(
        default='app.bsky.unspecced.getPostThreadOtherV2#threadItem', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

if t.TYPE_CHECKING:
    from atproto_client import models

ReasonType = t.Union[
    'models.ComAtprotoModerationDefs.ReasonSpam',
    'models.ComAtprotoModerationDefs.ReasonViolation',
    'models.ComAtprotoModerationDefs.ReasonMisleading',
    'models.ComAtprotoModerationDefs.ReasonSexual',
    'models.ComAtprotoModerationDefs.ReasonRude',
    'models.ComAtprotoModerationDefs.ReasonOther',
    'models.ComAtprotoModerationDefs.ReasonAppeal',
    'models.ToolsOzoneReportDefs.ReasonAppeal',
    'models.ToolsOzoneReportDefs.ReasonOther',
    'models.ToolsOzoneReportDefs.ReasonViolenceAnimal',
    'models.ToolsOzoneReportDefs.ReasonViolenceThreats',
    'models.ToolsOzoneReportDefs.ReasonViolenceGraphicContent',
    'models.ToolsOzoneReportDefs.ReasonViolenceGlorification',
    'models.ToolsOzoneReportDefs.ReasonViolenceExtremistContent',
    'models.ToolsOzoneReportDefs.ReasonViolenceTrafficking',
    'models.ToolsOzoneReportDefs.ReasonViolenceOther',
    'models.ToolsOzoneReportDefs.ReasonSexualAbuseContent',
    'models.ToolsOzoneReportDefs.ReasonSexualNCII',
    'models.ToolsOzoneReportDefs.ReasonSexualDeepfake',
    'models.ToolsOzoneReportDefs.ReasonSexualAnimal',
    'models.ToolsOzoneReportDefs.ReasonSexualUnlabeled',
    'models.ToolsOzoneReportDefs.ReasonSexualOther',
    'models.ToolsOzoneReportDefs.ReasonChildSafetyCSAM',
    'models.ToolsOzoneReportDefs.ReasonChildSafetyGroom',
    'models.ToolsOzoneReportDefs.ReasonChildSafetyPrivacy',
    'models.ToolsOzoneReportDefs.ReasonChildSafetyHarassment',
    'models.ToolsOzoneReportDefs.ReasonChildSafetyOther',
    'models.ToolsOzoneReportDefs.ReasonHarassmentTroll',
    'models.ToolsOzoneReportDefs.ReasonHarassmentTargeted',
    'models.ToolsOzoneReportDefs.ReasonHarassmentHateSpeech',
    'models.ToolsOzoneReportDefs.ReasonHarassmentDoxxing',
    'models.ToolsOzoneReportDefs.ReasonHarassmentOther',
    'models.ToolsOzoneReportDefs.ReasonMisleadingBot',
    'models.ToolsOzoneReportDefs.ReasonMisleadingImpersonation',
    'models.ToolsOzoneReportDefs.ReasonMisleadingSpam',
    'models.ToolsOzoneReportDefs.ReasonMisleadingScam',
    'models.ToolsOzoneReportDefs.ReasonMisleadingElections',
    'models.ToolsOzoneReportDefs.ReasonMisleadingOther',
    'models.ToolsOzoneReportDefs.ReasonRuleSiteSecurity',
    'models.ToolsOzoneReportDefs.ReasonRuleProhibitedSales',
    'models.ToolsOzoneReportDefs.ReasonRuleBanEvasion',
    'models.ToolsOzoneReportDefs.ReasonRuleOther',
    'models.ToolsOzoneReportDefs.ReasonSelfHarmContent',
    'models.ToolsOzoneReportDefs.ReasonSelfHarmED',
    'models.ToolsOzoneReportDefs.ReasonSelfHarmStunts',
    'models.ToolsOzoneReportDefs.ReasonSelfHarmSubstances',
    'models.ToolsOzoneReportDefs.ReasonSelfHarmOther',
    str,
]  #: Reason type

ReasonSpam = t.Literal[
    'com.atproto.moderation.defs#reasonSpam'
]  #: Spam: frequent unwanted promotion, replies, mentions. Prefer new lexicon definition `tools.ozone.report.defs#reasonMisleadingSpam`.

ReasonViolation = t.Literal[
    'com.atproto.moderation.defs#reasonViolation'
]  #: Direct violation of server rules, laws, terms of service. Prefer new lexicon definition `tools.ozone.report.defs#reasonRuleOther`.

ReasonMisleading = t.Literal[
    'com.atproto.moderation.defs#reasonMisleading'
]  #: Misleading identity, affiliation, or content. Prefer new lexicon definition `tools.ozone.report.defs#reasonMisleadingOther`.

ReasonSexual = t.Literal[
    'com.atproto.moderation.defs#reasonSexual'
]  #: Unwanted or mislabeled sexual content. Prefer new lexicon definition `tools.ozone.report.defs#reasonSexualUnlabeled`.

ReasonRude = t.Literal[
    'com.atproto.moderation.defs#reasonRude'
]  #: Rude, harassing, explicit, or otherwise unwelcoming behavior. Prefer new lexicon definition `tools.ozone.report.defs#reasonHarassmentOther`.

ReasonOther = t.Literal[
    'com.atproto.moderation.defs#reasonOther'
]  #: Reports not falling under another report category. Prefer new lexicon definition `tools.ozone.report.defs#reasonOther`.

ReasonAppeal = t.Literal['com.atproto.moderation.defs#reasonAppeal']  #: Appeal a previously taken moderation action

SubjectType = t.Union[
    t.Literal['account'], t.Literal['record'], t.Literal['chat'], str
]  #: Tag describing a type of subject that might be reported.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`tools.ozone.verification.revokeVerifications`."""

    uris: t.List[string_formats.AtUri] = Field(
        max_length=100
    )  #: Array of verification record uris to revoke. The AT-URI of the verification record to revoke.
    revoke_reason: te.Annotated[t.Optional[str], Field(max_length=1000)] = (
        None  #: Reason for revoking the verification. This is optional and can be omitted if not needed.
    )


class DataDict(t.TypedDict):
    uris: t.List[
        string_formats.AtUri
    ]  #: Array of verification record uris to revoke. The AT-URI of the verification record to revoke.
    revoke_reason: te.NotRequired[
        t.Optional[str]
    ]  #: Reason for revoking the verification. This is optional and can be omitted if not needed.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`tools.ozone.verification.revokeVerifications`."""

    failed_revocations: t.List[
        'models.ToolsOzoneVerificationRevokeVerifications.RevokeError'
    ]  #: List of verification uris that couldn't be revoked, including failure reasons.
    revoked_verifications: t.List[string_formats.AtUri]  #: List of verification uris successfully revoked.


class RevokeError(base.ModelBase):
    """Definition model for :obj:`tools.ozone.verification.revokeVerifications`. Error object for failed revocations."""

    error: str  #: Description of the error that occurred during revocation.
    uri: string_formats.AtUri  #: The AT-URI of the verification record that failed to revoke.

    py_type: t.Literal['tools.ozone.verification.revokeVerifications#revokeError'] = Field(
        default='tools.ozone.verification.revokeVerifications#revokeError', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`tools.ozone.moderation.cancelScheduledActions`."""

    subjects: t.List[string_formats.Did] = Field(
        max_length=100
    )  #: Array of DID subjects to cancel scheduled actions for.
    comment: t.Optional[str] = None  #: Optional comment describing the reason for cancellation.


class DataDict(t.TypedDict):
    subjects: t.List[string_formats.Did]  #: Array of DID subjects to cancel scheduled actions for.
    comment: te.NotRequired[t.Optional[str]]  #: Optional comment describing the reason for cancellation.


class CancellationResults(base.ModelBase):
    """Definition model for :obj:`tools.ozone.moderation.cancelScheduledActions`."""

    failed: t.List[
        'models.ToolsOzoneModerationCancelScheduledActions.FailedCancellation'
    ]  #: DIDs for which cancellation failed with error details.
    succeeded: t.List[string_formats.Did]  #: DIDs for which all pending scheduled actions were successfully cancelled.

    py_type: t.Literal['tools.ozone.moderation.cancelScheduledActions#cancellationResults'] = Field(
        default='tools.ozone.moderation.cancelScheduledActions#cancellationResults', alias='$type', frozen=True
    )


class FailedCancellation(base.ModelBase):
    """Definition model for :obj:`tools.ozone.moderation.cancelScheduledActions`."""

    did: string_formats.Did  #: Did.
    error: str  #: Error.
    error_code: t.Optional[str] = None  #: Error code.

    py_type: t.Literal['tools.ozone.moderation.cancelScheduledActions#failedCancellation'] = Field(
        default='tools.ozone.moderation.cancelScheduledActions#failedCancellation', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`tools.ozone.moderation.emitEvent`."""

    created_by: string_formats.Did  #: Created by.
    event: te.Annotated[
        t.Union[
            'models.ToolsOzoneModerationDefs.ModEventTakedown',
            'models.ToolsOzoneModerationDefs.ModEventAcknowledge',
            'models.ToolsOzoneModerationDefs.ModEventEscalate',
            'models.ToolsOzoneModerationDefs.ModEventComment',
            'models.ToolsOzoneModerationDefs.ModEventLabel',
            'models.ToolsOzoneModerationDefs.ModEventReport',
            'models.ToolsOzoneModerationDefs.ModEventMute',
            'models.ToolsOzoneModerationDefs.ModEventUnmute',
            'models.ToolsOzoneModerationDefs.ModEventMuteReporter',
            'models.ToolsOzoneModerationDefs.ModEventUnmuteReporter',
            'models.ToolsOzoneModerationDefs.ModEventReverseTakedown',
            'models.ToolsOzoneModerationDefs.ModEventResolveAppeal',
            'models.ToolsOzoneModerationDefs.ModEventEmail',
            'models.ToolsOzoneModerationDefs.ModEventDivert',
            'models.ToolsOzoneModerationDefs.ModEventTag',
            'models.ToolsOzoneModerationDefs.AccountEvent',
            'models.ToolsOzoneModerationDefs.IdentityEvent',
            'models.ToolsOzoneModerationDefs.RecordEvent',
            'models.ToolsOzoneModerationDefs.ModEventPriorityScore',
            'models.ToolsOzoneModerationDefs.AgeAssuranceEvent',
            'models.ToolsOzoneModerationDefs.AgeAssuranceOverrideEvent',
            'models.ToolsOzoneModerationDefs.RevokeAccountCredentialsEvent',
            'models.ToolsOzoneModerationDefs.ScheduleTakedownEvent',
            'models.ToolsOzoneModerationDefs.CancelScheduledTakedownEvent',
        ],
        Field(discriminator='py_type'),
    ]  #: Event.
    subject: te.Annotated[
        t.Union['models.ComAtprotoAdminDefs.RepoRef', 'models.ComAtprotoRepoStrongRef.Main'],
        Field(discriminator='py_type'),
    ]  #: Subject.
    external_id: t.Optional[str] = (
        None  #: An optional external ID for the event, used to deduplicate events from external systems. Fails when an event of same type with the same external ID exists for the same subject.
    )
    mod_tool: t.Optional['models.ToolsOzoneModerationDefs.ModTool'] = None  #: Mod tool.
    subject_blob_cids: t.Optional[t.List[string_formats.Cid]] = None  #: Subject blob cids.


class DataDict(t.TypedDict):
    created_by: string_formats.Did  #: Created by.
    event: te.Annotated[
        t.Union[
            'models.ToolsOzoneModerationDefs.ModEventTakedown',
            'models.ToolsOzoneModerationDefs.ModEventAcknowledge',
            'models.ToolsOzoneModerationDefs.ModEventEscalate',
            'models.ToolsOzoneModerationDefs.ModEventComment',
            'models.ToolsOzoneModerationDefs.ModEventLabel',
            'models.ToolsOzoneModerationDefs.ModEventReport',
            'models.ToolsOzoneModerationDefs.ModEventMute',
            'models.ToolsOzoneModerationDefs.ModEventUnmute',
            'models.ToolsOzoneModerationDefs.ModEventMuteReporter',
            'models.ToolsOzoneModerationDefs.ModEventUnmuteReporter',
            'models.ToolsOzoneModerationDefs.ModEventReverseTakedown',
            'models.ToolsOzoneModerationDefs.ModEventResolveAppeal',
            'models.ToolsOzoneModerationDefs.ModEventEmail',
            'models.ToolsOzoneModerationDefs.ModEventDivert',
            'models.ToolsOzoneModerationDefs.ModEventTag',
            'models.ToolsOzoneModerationDefs.AccountEvent',
            'models.ToolsOzoneModerationDefs.IdentityEvent',
            'models.ToolsOzoneModerationDefs.RecordEvent',
            'models.ToolsOzoneModerationDefs.ModEventPriorityScore',
            'models.ToolsOzoneModerationDefs.AgeAssuranceEvent',
            'models.ToolsOzoneModerationDefs.AgeAssuranceOverrideEvent',
            'models.ToolsOzoneModerationDefs.RevokeAccountCredentialsEvent',
            'models.ToolsOzoneModerationDefs.ScheduleTakedownEvent',
            'models.ToolsOzoneModerationDefs.CancelScheduledTakedownEvent',
        ],
        Field(discriminator='py_type'),
    ]  #: Event.
    subject: te.Annotated[
        t.Union['models.ComAtprotoAdminDefs.RepoRef', 'models.ComAtprotoRepoStrongRef.Main'],
        Field(discriminator='py_type'),
    ]  #: Subject.
    external_id: te.NotRequired[
        t.Optional[str]
    ]  #: An optional external ID for the event, used to deduplicate events from external systems. Fails when an event of same type with the same external ID exists for the same subject.
    mod_tool: te.NotRequired[t.Optional['models.ToolsOzoneModerationDefs.ModTool']]  #: Mod tool.
    subject_blob_cids: te.NotRequired[t.Optional[t.List[string_formats.Cid]]]  #: Subject blob cids.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`tools.ozone.verification.grantVerifications`."""

    verifications: t.List['models.ToolsOzoneVerificationGrantVerifications.VerificationInput'] = Field(
        max_length=100
    )  #: Array of verification requests to process.


class DataDict(t.TypedDict):
    verifications: t.List[
        'models.ToolsOzoneVerificationGrantVerifications.VerificationInput'
    ]  #: Array of verification requests to process.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`tools.ozone.verification.grantVerifications`."""

    failed_verifications: t.List['models.ToolsOzoneVerificationGrantVerifications.GrantError']  #: Failed verifications.
    verifications: t.List['models.ToolsOzoneVerificationDefs.VerificationView']  #: Verifications.


class VerificationInput(base.ModelBase):
    """Definition model for :obj:`tools.ozone.verification.grantVerifications`."""

    display_name: str  #: Display name of the subject the verification applies to at the moment of verifying.
    handle: string_formats.Handle  #: Handle of the subject the verification applies to at the moment of verifying.
    subject: string_formats.Did  #: The did of the subject being verified.
    created_at: t.Optional[string_formats.DateTime] = (
        None  #: Timestamp for verification record. Defaults to current time when not specified.
    )

    py_type: t.Literal['tools.ozone.verification.grantVerifications#verificationInput'] = Field(
        default='tools.ozone.verification.grantVerifications#verificationInput', alias='$type', frozen=True
    )


class GrantError(base.ModelBase):
    """Definition model for :obj:`tools.ozone.verification.grantVerifications`. Error object for failed verifications."""

    error: str  #: Error message describing the reason for failure.
    subject: string_formats.Did  #: The did of the subject being verified.

    py_type: t.Literal['tools.ozone.verification.grantVerifications#grantError'] = Field(
        default='tools.ozone.verification.grantVerifications#grantError', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`tools.ozone.moderation.listScheduledActions`."""

    statuses: t.List[
        t.Union[t.Literal['pending'], t.Literal['executed'], t.Literal['cancelled'], t.Literal['failed'], str]
    ] = Field(min_length=1)  #: Filter actions by status.
    cursor: t.Optional[str] = None  #: Cursor for pagination.
    ends_before: t.Optional[string_formats.DateTime] = None  #: Filter actions scheduled to execute before this time.
    limit: te.Annotated[t.Optional[int], Field(ge=1, le=100)] = None  #: Maximum number of results to return.
    starts_after: t.Optional[string_formats.DateTime] = None  #: Filter actions scheduled to execute after this time.
    subjects: te.Annotated[t.Optional[t.List[string_formats.Did]], Field(max_length=100)] = (
        None  #: Filter actions for specific DID subjects.
    )


class DataDict(t.TypedDict):
    statuses: t.List[
        t.Union[t.Literal['pending'], t.Literal['executed'], t.Literal['cancelled'], t.Literal['failed'], str]
    ]  #: Filter actions by status.
    cursor: te.NotRequired[t.Optional[str]]  #: Cursor for pagination.
    ends_before: te.NotRequired[
        t.Optional[string_formats.DateTime]
    ]  #: Filter actions scheduled to execute before this time.
    limit: te.NotRequired[t.Optional[int]]  #: Maximum number of results to return.
    starts_after: te.NotRequired[
        t.Optional[string_formats.DateTime]
    ]  #: Filter actions scheduled to execute after this time.
    subjects: te.NotRequired[t.Optional[t.List[string_formats.Did]]]  #: Filter actions for specific DID subjects.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`tools.ozone.moderation.listScheduledActions`."""

    actions: t.List['models.ToolsOzoneModerationDefs.ScheduledActionView']  #: Actions.
    cursor: t.Optional[str] = None  #: Cursor for next page of results.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`tools.ozone.moderation.getAccountTimeline`."""

    did: string_formats.Did  #: Did.


class ParamsDict(t.TypedDict):
    did: string_formats.Did  #: Did.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`tools.ozone.moderation.getAccountTimeline`."""

    timeline: t.List['models.ToolsOzoneModerationGetAccountTimeline.TimelineItem']  #: Timeline.


class TimelineItem(base.ModelBase):
    """Definition model for :obj:`tools.ozone.moderation.getAccountTimeline`."""

    day: str  #: Day.
    summary: t.List['models.ToolsOzoneModerationGetAccountTimeline.TimelineItemSummary']  #: Summary.

    py_type: t.Literal['tools.ozone.moderation.getAccountTimeline#timelineItem'] = Field(
        default='tools.ozone.moderation.getAccountTimeline#timelineItem', alias='$type', frozen=True
    )


class TimelineItemSummary(base.ModelBase):
    """Definition model for :obj:`tools.ozone.moderation.getAccountTimeline`."""

    count: int  #: Count.
    event_subject_type: t.Union[
        t.Literal['account'], t.Literal['record'], t.Literal['chat'], str
    ]  #: Event subject type.
    event_type: t.Union[
        'models.ToolsOzoneModerationDefs.ModEventTakedown',
        'models.ToolsOzoneModerationDefs.ModEventReverseTakedown',
        'models.ToolsOzoneModerationDefs.ModEventComment',
        'models.ToolsOzoneModerationDefs.ModEventReport',
        'models.ToolsOzoneModerationDefs.ModEventLabel',
        'models.ToolsOzoneModerationDefs.ModEventAcknowledge',
        'models.ToolsOzoneModerationDefs.ModEventEscalate',
        'models.ToolsOzoneModerationDefs.ModEventMute',
        'models.ToolsOzoneModerationDefs.ModEventUnmute',
        'models.ToolsOzoneModerationDefs.ModEventMuteReporter',
        'models.ToolsOzoneModerationDefs.ModEventUnmuteReporter',
        'models.ToolsOzoneModerationDefs.ModEventEmail',
        'models.ToolsOzoneModerationDefs.ModEventResolveAppeal',
        'models.ToolsOzoneModerationDefs.ModEventDivert',
        'models.ToolsOzoneModerationDefs.ModEventTag',
        'models.ToolsOzoneModerationDefs.AccountEvent',
        'models.ToolsOzoneModerationDefs.IdentityEvent',
        'models.ToolsOzoneModerationDefs.RecordEvent',
        'models.ToolsOzoneModerationDefs.ModEventPriorityScore',
        'models.ToolsOzoneModerationDefs.RevokeAccountCredentialsEvent',
        'models.ToolsOzoneModerationDefs.AgeAssuranceEvent',
        'models.ToolsOzoneModerationDefs.AgeAssuranceOverrideEvent',
        'models.ToolsOzoneModerationDefs.TimelineEventPlcCreate',
        'models.ToolsOzoneModerationDefs.TimelineEventPlcOperation',
        'models.ToolsOzoneModerationDefs.TimelineEventPlcTombstone',
        'models.ToolsOzoneHostingGetAccountHistory.AccountCreated',
        'models.ToolsOzoneHostingGetAccountHistory.EmailConfirmed',
        'models.ToolsOzoneHostingGetAccountHistory.PasswordUpdated',
        'models.ToolsOzoneHostingGetAccountHistory.HandleUpdated',
        'models.ToolsOzoneModerationDefs.ScheduleTakedownEvent',
        'models.ToolsOzoneModerationDefs.CancelScheduledTakedownEvent',
        str,
    ]  #: Event type.

    py_type: t.Literal['tools.ozone.moderation.getAccountTimeline#timelineItemSummary'] = Field(
        default='tools.ozone.moderation.getAccountTimeline#timelineItemSummary', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
    from atproto_client.models.unknown_type import UnknownType
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`com.atproto.moderation.createReport`."""

    reason_type: (
        'models.ComAtprotoModerationDefs.ReasonType'  #: Indicates the broad category of violation the report is for.
    )
    subject: te.Annotated[
        t.Union['models.ComAtprotoAdminDefs.RepoRef', 'models.ComAtprotoRepoStrongRef.Main'],
        Field(discriminator='py_type'),
    ]  #: Subject.
    mod_tool: t.Optional['models.ComAtprotoModerationCreateReport.ModTool'] = None  #: Mod tool.
    reason: te.Annotated[t.Optional[str], Field(max_length=20000)] = (
        None  #: Additional context about the content and violation.
    )


class DataDict(t.TypedDict):
    reason_type: (
        'models.ComAtprotoModerationDefs.ReasonType'  #: Indicates the broad category of violation the report is for.
    )
    subject: te.Annotated[
        t.Union['models.ComAtprotoAdminDefs.RepoRef', 'models.ComAtprotoRepoStrongRef.Main'],
        Field(discriminator='py_type'),
    ]  #: Subject.
    mod_tool: te.NotRequired[t.Optional['models.ComAtprotoModerationCreateReport.ModTool']]  #: Mod tool.
    reason: te.NotRequired[t.Optional[str]]  #: Additional context about the content and violation.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`com.atproto.moderation.createReport`."""

    created_at: string_formats.DateTime  #: Created at.
    id: int  #: Id.
    reason_type: 'models.ComAtprotoModerationDefs.ReasonType'  #: Reason type.
    reported_by: string_formats.Did  #: Reported by.
    subject: te.Annotated[
        t.Union['models.ComAtprotoAdminDefs.RepoRef', 'models.ComAtprotoRepoStrongRef.Main'],
        Field(discriminator='py_type'),
    ]  #: Subject.
    reason: te.Annotated[t.Optional[str], Field(max_length=20000)] = None  #: Reason.


class ModTool(base.ModelBase):
    """Definition model for :obj:`com.atproto.moderation.createReport`. Moderation tool information for tracing the source of the action."""

    name: str  #: Name/identifier of the source (e.g., 'bsky-app/android', 'bsky-web/chrome').
    meta: t.Optional['UnknownType'] = None  #: Additional arbitrary metadata about the source.

    py_type: t.Literal['com.atproto.moderation.createReport#modTool'] = Field(
        default='com.atproto.moderation.createReport#modTool', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`app.bsky.notification.putActivitySubscription`."""

    activity_subscription: 'models.AppBskyNotificationDefs.ActivitySubscription'  #: Activity subscription.
    subject: string_formats.Did  #: Subject.


class DataDict(t.TypedDict):
    activity_subscription: 'models.AppBskyNotificationDefs.ActivitySubscription'  #: Activity subscription.
    subject: string_formats.Did  #: Subject.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`app.bsky.notification.putActivitySubscription`."""

    subject: string_formats.Did  #: Subject.
    activity_subscription: t.Optional['models.AppBskyNotificationDefs.ActivitySubscription'] = (
        None  #: Activity subscription.
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`app.bsky.graph.getListsWithMembership`."""

    actor: string_formats.AtIdentifier  #: The account (actor) to check for membership.
    cursor: t.Optional[str] = None  #: Cursor.
    limit: te.Annotated[t.Optional[int], Field(ge=1, le=100)] = None  #: Limit.
    purposes: t.Optional[t.List[t.Union[t.Literal['modlist'], t.Literal['curatelist'], str]]] = (
        None  #: Optional filter by list purpose. If not specified, all supported types are returned.
    )


class ParamsDict(t.TypedDict):
    actor: string_formats.AtIdentifier  #: The account (actor) to check for membership.
    cursor: te.NotRequired[t.Optional[str]]  #: Cursor.
    limit: te.NotRequired[t.Optional[int]]  #: Limit.
    purposes: te.NotRequired[
        t.Optional[t.List[t.Union[t.Literal['modlist'], t.Literal['curatelist'], str]]]
    ]  #: Optional filter by list purpose. If not specified, all supported types are returned.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`app.bsky.graph.getListsWithMembership`."""

    lists_with_membership: t.List[
        'models.AppBskyGraphGetListsWithMembership.ListWithMembership'
    ]  #: Lists with membership.
    cursor: t.Optional[str] = None  #: Cursor.


class ListWithMembership(base.ModelBase):
    """Definition model for :obj:`app.bsky.graph.getListsWithMembership`. A list and an optional list item indicating membership of a target user to that list."""

    list: 'models.AppBskyGraphDefs.ListView'  #: List.
    list_item: t.Optional['models.AppBskyGraphDefs.ListItemView'] = None  #: List item.

    py_type: t.Literal['app.bsky.graph.getListsWithMembership#listWithMembership'] = Field(
        default='app.bsky.graph.getListsWithMembership#listWithMembership', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

if t.TYPE_CHECKING:
    from atproto_client import models

ReasonType = t.Union[
    'models.ToolsOzoneReportDefs.ReasonAppeal',
    'models.ToolsOzoneReportDefs.ReasonOther',
    'models.ToolsOzoneReportDefs.ReasonViolenceAnimal',
    'models.ToolsOzoneReportDefs.ReasonViolenceThreats',
    'models.ToolsOzoneReportDefs.ReasonViolenceGraphicContent',
    'models.ToolsOzoneReportDefs.ReasonViolenceGlorification',
    'models.ToolsOzoneReportDefs.ReasonViolenceExtremistContent',
    'models.ToolsOzoneReportDefs.ReasonViolenceTrafficking',
    'models.ToolsOzoneReportDefs.ReasonViolenceOther',
    'models.ToolsOzoneReportDefs.ReasonSexualAbuseContent',
    'models.ToolsOzoneReportDefs.ReasonSexualNCII',
    'models.ToolsOzoneReportDefs.ReasonSexualDeepfake',
    'models.ToolsOzoneReportDefs.ReasonSexualAnimal',
    'models.ToolsOzoneReportDefs.ReasonSexualUnlabeled',
    'models.ToolsOzoneReportDefs.ReasonSexualOther',
    'models.ToolsOzoneReportDefs.ReasonChildSafetyCSAM',
    'models.ToolsOzoneReportDefs.ReasonChildSafetyGroom',
    'models.ToolsOzoneReportDefs.ReasonChildSafetyPrivacy',
    'models.ToolsOzoneReportDefs.ReasonChildSafetyHarassment',
    'models.ToolsOzoneReportDefs.ReasonChildSafetyOther',
    'models.ToolsOzoneReportDefs.ReasonHarassmentTroll',
    'models.ToolsOzoneReportDefs.ReasonHarassmentTargeted',
    'models.ToolsOzoneReportDefs.ReasonHarassmentHateSpeech',
    'models.ToolsOzoneReportDefs.ReasonHarassmentDoxxing',
    'models.ToolsOzoneReportDefs.ReasonHarassmentOther',
    'models.ToolsOzoneReportDefs.ReasonMisleadingBot',
    'models.ToolsOzoneReportDefs.ReasonMisleadingImpersonation',
    'models.ToolsOzoneReportDefs.ReasonMisleadingSpam',
    'models.ToolsOzoneReportDefs.ReasonMisleadingScam',
    'models.ToolsOzoneReportDefs.ReasonMisleadingElections',
    'models.ToolsOzoneReportDefs.ReasonMisleadingOther',
    'models.ToolsOzoneReportDefs.ReasonRuleSiteSecurity',
    'models.ToolsOzoneReportDefs.ReasonRuleProhibitedSales',
    'models.ToolsOzoneReportDefs.ReasonRuleBanEvasion',
    'models.ToolsOzoneReportDefs.ReasonRuleOther',
    'models.ToolsOzoneReportDefs.ReasonSelfHarmContent',
    'models.ToolsOzoneReportDefs.ReasonSelfHarmED',
    'models.ToolsOzoneReportDefs.ReasonSelfHarmStunts',
    'models.ToolsOzoneReportDefs.ReasonSelfHarmSubstances',
    'models.ToolsOzoneReportDefs.ReasonSelfHarmOther',
    str,
]  #: Reason type

ReasonAppeal = t.Literal['tools.ozone.report.defs#reasonAppeal']  #: Appeal a previously taken moderation action

ReasonOther = t.Literal['tools.ozone.report.defs#reasonOther']  #: An issue not included in these options

ReasonViolenceAnimal = t.Literal['tools.ozone.report.defs#reasonViolenceAnimal']  #: Animal welfare violations

ReasonViolenceThreats = t.Literal['tools.ozone.report.defs#reasonViolenceThreats']  #: Threats or incitement

ReasonViolenceGraphicContent = t.Literal[
    'tools.ozone.report.defs#reasonViolenceGraphicContent'
]  #: Graphic violent content

ReasonViolenceGlorification = t.Literal[
    'tools.ozone.report.defs#reasonViolenceGlorification'
]  #: Glorification of violence

ReasonViolenceExtremistContent = t.Literal[
    'tools.ozone.report.defs#reasonViolenceExtremistContent'
]  #: Extremist content. These reports will be sent only be sent to the application's Moderation Authority.

ReasonViolenceTrafficking = t.Literal['tools.ozone.report.defs#reasonViolenceTrafficking']  #: Human trafficking

ReasonViolenceOther = t.Literal['tools.ozone.report.defs#reasonViolenceOther']  #: Other violent content

ReasonSexualAbuseContent = t.Literal['tools.ozone.report.defs#reasonSexualAbuseContent']  #: Adult sexual abuse content

ReasonSexualNCII = t.Literal['tools.ozone.report.defs#reasonSexualNCII']  #: Non-consensual intimate imagery

ReasonSexualDeepfake = t.Literal['tools.ozone.report.defs#reasonSexualDeepfake']  #: Deepfake adult content

ReasonSexualAnimal = t.Literal['tools.ozone.report.defs#reasonSexualAnimal']  #: Animal sexual abuse

ReasonSexualUnlabeled = t.Literal['tools.ozone.report.defs#reasonSexualUnlabeled']  #: Unlabelled adult content

ReasonSexualOther = t.Literal['tools.ozone.report.defs#reasonSexualOther']  #: Other sexual violence content

ReasonChildSafetyCSAM = t.Literal[
    'tools.ozone.report.defs#reasonChildSafetyCSAM'
]  #: Child sexual abuse material (CSAM). These reports will be sent only be sent to the application's Moderation Authority.

ReasonChildSafetyGroom = t.Literal[
    'tools.ozone.report.defs#reasonChildSafetyGroom'
]  #: Grooming or predatory behavior. These reports will be sent only be sent to the application's Moderation Authority.

ReasonChildSafetyPrivacy = t.Literal[
    'tools.ozone.report.defs#reasonChildSafetyPrivacy'
]  #: Privacy violation involving a minor

ReasonChildSafetyHarassment = t.Literal[
    'tools.ozone.report.defs#reasonChildSafetyHarassment'
]  #: Harassment or bullying of minors

ReasonChildSafetyOther = t.Literal[
    'tools.ozone.report.defs#reasonChildSafetyOther'
]  #: Other child safety. These reports will be sent only be sent to the application's Moderation Authority.

ReasonHarassmentTroll = t.Literal['tools.ozone.report.defs#reasonHarassmentTroll']  #: Trolling

ReasonHarassmentTargeted = t.Literal['tools.ozone.report.defs#reasonHarassmentTargeted']  #: Targeted harassment

ReasonHarassmentHateSpeech = t.Literal['tools.ozone.report.defs#reasonHarassmentHateSpeech']  #: Hate speech

ReasonHarassmentDoxxing = t.Literal['tools.ozone.report.defs#reasonHarassmentDoxxing']  #: Doxxing

ReasonHarassmentOther = t.Literal[
    'tools.ozone.report.defs#reasonHarassmentOther'
]  #: Other harassing or hateful content

ReasonMisleadingBot = t.Literal['tools.ozone.report.defs#reasonMisleadingBot']  #: Fake account or bot

ReasonMisleadingImpersonation = t.Literal['tools.ozone.report.defs#reasonMisleadingImpersonation']  #: Impersonation

ReasonMisleadingSpam = t.Literal['tools.ozone.report.defs#reasonMisleadingSpam']  #: Spam

ReasonMisleadingScam = t.Literal['tools.ozone.report.defs#reasonMisleadingScam']  #: Scam

ReasonMisleadingElections = t.Literal[
    'tools.ozone.report.defs#reasonMisleadingElections'
]  #: False information about elections

ReasonMisleadingOther = t.Literal['tools.ozone.report.defs#reasonMisleadingOther']  #: Other misleading content

ReasonRuleSiteSecurity = t.Literal['tools.ozone.report.defs#reasonRuleSiteSecurity']  #: Hacking or system attacks

ReasonRuleProhibitedSales = t.Literal[
    'tools.ozone.report.defs#reasonRuleProhibitedSales'
]  #: Promoting or selling prohibited items or services

ReasonRuleBanEvasion = t.Literal['tools.ozone.report.defs#reasonRuleBanEvasion']  #: Banned user returning

ReasonRuleOther = t.Literal['tools.ozone.report.defs#reasonRuleOther']  #: Other

ReasonSelfHarmContent = t.Literal[
    'tools.ozone.report.defs#reasonSelfHarmContent'
]  #: Content promoting or depicting self-harm

ReasonSelfHarmED = t.Literal['tools.ozone.report.defs#reasonSelfHarmED']  #: Eating disorders

ReasonSelfHarmStunts = t.Literal['tools.ozone.report.defs#reasonSelfHarmStunts']  #: Dangerous challenges or activities

ReasonSelfHarmSubstances = t.Literal[
    'tools.ozone.report.defs#reasonSelfHarmSubstances'
]  #: Dangerous substances or drug abuse

ReasonSelfHarmOther = t.Literal['tools.ozone.report.defs#reasonSelfHarmOther']  #: Other dangerous content



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

from pydantic import Field

from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`tools.ozone.set.deleteValues`."""

    name: str  #: Name of the set to delete values from.
    values: t.List[str] = Field(min_length=1)  #: Array of string values to delete from the set.


class DataDict(t.TypedDict):
    name: str  #: Name of the set to delete values from.
    values: t.List[str]  #: Array of string values to delete from the set.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`tools.ozone.moderation.scheduleAction`."""

    action: te.Annotated[
        t.Union['models.ToolsOzoneModerationScheduleAction.Takedown'], Field(discriminator='py_type')
    ]  #: Action.
    created_by: string_formats.Did  #: Created by.
    scheduling: 'models.ToolsOzoneModerationScheduleAction.SchedulingConfig'  #: Scheduling.
    subjects: t.List[string_formats.Did] = Field(max_length=100)  #: Array of DID subjects to schedule the action for.
    mod_tool: t.Optional['models.ToolsOzoneModerationDefs.ModTool'] = (
        None  #: This will be propagated to the moderation event when it is applied.
    )


class DataDict(t.TypedDict):
    action: te.Annotated[
        t.Union['models.ToolsOzoneModerationScheduleAction.Takedown'], Field(discriminator='py_type')
    ]  #: Action.
    created_by: string_formats.Did  #: Created by.
    scheduling: 'models.ToolsOzoneModerationScheduleAction.SchedulingConfig'  #: Scheduling.
    subjects: t.List[string_formats.Did]  #: Array of DID subjects to schedule the action for.
    mod_tool: te.NotRequired[
        t.Optional['models.ToolsOzoneModerationDefs.ModTool']
    ]  #: This will be propagated to the moderation event when it is applied.


class Takedown(base.ModelBase):
    """Definition model for :obj:`tools.ozone.moderation.scheduleAction`. Schedule a takedown action."""

    acknowledge_account_subjects: t.Optional[bool] = (
        None  #: If true, all other reports on content authored by this account will be resolved (acknowledged).
    )
    comment: t.Optional[str] = None  #: Comment.
    duration_in_hours: t.Optional[int] = (
        None  #: Indicates how long the takedown should be in effect before automatically expiring.
    )
    policies: te.Annotated[t.Optional[t.List[str]], Field(max_length=5)] = (
        None  #: Names/Keywords of the policies that drove the decision.
    )

    py_type: t.Literal['tools.ozone.moderation.scheduleAction#takedown'] = Field(
        default='tools.ozone.moderation.scheduleAction#takedown', alias='$type', frozen=True
    )


class SchedulingConfig(base.ModelBase):
    """Definition model for :obj:`tools.ozone.moderation.scheduleAction`. Configuration for when the action should be executed."""

    execute_after: t.Optional[string_formats.DateTime] = (
        None  #: Earliest time to execute the action (for randomized scheduling).
    )
    execute_at: t.Optional[string_formats.DateTime] = None  #: Exact time to execute the action.
    execute_until: t.Optional[string_formats.DateTime] = (
        None  #: Latest time to execute the action (for randomized scheduling).
    )

    py_type: t.Literal['tools.ozone.moderation.scheduleAction#schedulingConfig'] = Field(
        default='tools.ozone.moderation.scheduleAction#schedulingConfig', alias='$type', frozen=True
    )


class ScheduledActionResults(base.ModelBase):
    """Definition model for :obj:`tools.ozone.moderation.scheduleAction`."""

    failed: t.List['models.ToolsOzoneModerationScheduleAction.FailedScheduling']  #: Failed.
    succeeded: t.List[string_formats.Did]  #: Succeeded.

    py_type: t.Literal['tools.ozone.moderation.scheduleAction#scheduledActionResults'] = Field(
        default='tools.ozone.moderation.scheduleAction#scheduledActionResults', alias='$type', frozen=True
    )


class FailedScheduling(base.ModelBase):
    """Definition model for :obj:`tools.ozone.moderation.scheduleAction`."""

    error: str  #: Error.
    subject: string_formats.Did  #: Subject.
    error_code: t.Optional[str] = None  #: Error code.

    py_type: t.Literal['tools.ozone.moderation.scheduleAction#failedScheduling'] = Field(
        default='tools.ozone.moderation.scheduleAction#failedScheduling', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

from pydantic import Field

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`chat.bsky.convo.addReaction`."""

    convo_id: str  #: Convo id.
    message_id: str  #: Message id.
    value: str = Field(min_length=1, max_length=64)  #: Value.


class DataDict(t.TypedDict):
    convo_id: str  #: Convo id.
    message_id: str  #: Message id.
    value: str  #: Value.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`chat.bsky.convo.addReaction`."""

    message: 'models.ChatBskyConvoDefs.MessageView'  #: Message.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`app.bsky.notification.putPreferencesV2`."""

    chat: t.Optional['models.AppBskyNotificationDefs.ChatPreference'] = None  #: Chat.
    follow: t.Optional['models.AppBskyNotificationDefs.FilterablePreference'] = None  #: Follow.
    like: t.Optional['models.AppBskyNotificationDefs.FilterablePreference'] = None  #: Like.
    like_via_repost: t.Optional['models.AppBskyNotificationDefs.FilterablePreference'] = None  #: Like via repost.
    mention: t.Optional['models.AppBskyNotificationDefs.FilterablePreference'] = None  #: Mention.
    quote: t.Optional['models.AppBskyNotificationDefs.FilterablePreference'] = None  #: Quote.
    reply: t.Optional['models.AppBskyNotificationDefs.FilterablePreference'] = None  #: Reply.
    repost: t.Optional['models.AppBskyNotificationDefs.FilterablePreference'] = None  #: Repost.
    repost_via_repost: t.Optional['models.AppBskyNotificationDefs.FilterablePreference'] = None  #: Repost via repost.
    starterpack_joined: t.Optional['models.AppBskyNotificationDefs.Preference'] = None  #: Starterpack joined.
    subscribed_post: t.Optional['models.AppBskyNotificationDefs.Preference'] = None  #: Subscribed post.
    unverified: t.Optional['models.AppBskyNotificationDefs.Preference'] = None  #: Unverified.
    verified: t.Optional['models.AppBskyNotificationDefs.Preference'] = None  #: Verified.


class DataDict(t.TypedDict):
    chat: te.NotRequired[t.Optional['models.AppBskyNotificationDefs.ChatPreference']]  #: Chat.
    follow: te.NotRequired[t.Optional['models.AppBskyNotificationDefs.FilterablePreference']]  #: Follow.
    like: te.NotRequired[t.Optional['models.AppBskyNotificationDefs.FilterablePreference']]  #: Like.
    like_via_repost: te.NotRequired[
        t.Optional['models.AppBskyNotificationDefs.FilterablePreference']
    ]  #: Like via repost.
    mention: te.NotRequired[t.Optional['models.AppBskyNotificationDefs.FilterablePreference']]  #: Mention.
    quote: te.NotRequired[t.Optional['models.AppBskyNotificationDefs.FilterablePreference']]  #: Quote.
    reply: te.NotRequired[t.Optional['models.AppBskyNotificationDefs.FilterablePreference']]  #: Reply.
    repost: te.NotRequired[t.Optional['models.AppBskyNotificationDefs.FilterablePreference']]  #: Repost.
    repost_via_repost: te.NotRequired[
        t.Optional['models.AppBskyNotificationDefs.FilterablePreference']
    ]  #: Repost via repost.
    starterpack_joined: te.NotRequired[t.Optional['models.AppBskyNotificationDefs.Preference']]  #: Starterpack joined.
    subscribed_post: te.NotRequired[t.Optional['models.AppBskyNotificationDefs.Preference']]  #: Subscribed post.
    unverified: te.NotRequired[t.Optional['models.AppBskyNotificationDefs.Preference']]  #: Unverified.
    verified: te.NotRequired[t.Optional['models.AppBskyNotificationDefs.Preference']]  #: Verified.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`app.bsky.notification.putPreferencesV2`."""

    preferences: 'models.AppBskyNotificationDefs.Preferences'  #: Preferences.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
    from atproto_client.models.blob_ref import BlobRef
from atproto_client.models import base


class Record(base.RecordModelBase):
    """Record model for :obj:`app.bsky.graph.list`."""

    created_at: string_formats.DateTime  #: Created at.
    name: str = Field(min_length=1, max_length=64)  #: Display name for list; can not be empty.
    purpose: 'models.AppBskyGraphDefs.ListPurpose'  #: Defines the purpose of the list (aka, moderation-oriented or curration-oriented).
    avatar: t.Optional['BlobRef'] = None  #: Avatar.
    description: te.Annotated[t.Optional[str], Field(max_length=3000)] = None  #: Description.
    description_facets: t.Optional[t.List['models.AppBskyRichtextFacet.Main']] = None  #: Description facets.
    labels: t.Optional[
        te.Annotated[t.Union['models.ComAtprotoLabelDefs.SelfLabels'], Field(default=None, discriminator='py_type')]
    ] = None  #: Labels.

    py_type: t.Literal['app.bsky.graph.list'] = Field(default='app.bsky.graph.list', alias='$type', frozen=True)


class GetRecordResponse(base.SugarResponseModelBase):
    """Get record response for :obj:`models.AppBskyGraphList.Record`."""

    uri: str  #: The URI of the record.
    value: 'models.AppBskyGraphList.Record'  #: The record.
    cid: t.Optional[str] = None  #: The CID of the record.


class ListRecordsResponse(base.SugarResponseModelBase):
    """List records response for :obj:`models.AppBskyGraphList.Record`."""

    records: t.Dict[str, 'models.AppBskyGraphList.Record']  #: Map of URIs to records.
    cursor: t.Optional[str] = None  #: Next page cursor.


class CreateRecordResponse(base.SugarResponseModelBase):
    """Create record response for :obj:`models.AppBskyGraphList.Record`."""

    uri: str  #: The URI of the record.
    cid: str  #: The CID of the record.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class VerificationView(base.ModelBase):
    """Definition model for :obj:`tools.ozone.verification.defs`. Verification data for the associated subject."""

    created_at: string_formats.DateTime  #: Timestamp when the verification was created.
    display_name: str  #: Display name of the subject the verification applies to at the moment of verifying, which might not be the same at the time of viewing. The verification is only valid if the current displayName matches the one at the time of verifying.
    handle: string_formats.Handle  #: Handle of the subject the verification applies to at the moment of verifying, which might not be the same at the time of viewing. The verification is only valid if the current handle matches the one at the time of verifying.
    issuer: string_formats.Did  #: The user who issued this verification.
    subject: string_formats.Did  #: The subject of the verification.
    uri: string_formats.AtUri  #: The AT-URI of the verification record.
    issuer_profile: t.Optional[te.Annotated[t.Union['base.UnknownUnionModel'], Field(default=None)]] = (
        None  #: Issuer profile.
    )
    issuer_repo: t.Optional[
        te.Annotated[
            t.Union[
                'models.ToolsOzoneModerationDefs.RepoViewDetail', 'models.ToolsOzoneModerationDefs.RepoViewNotFound'
            ],
            Field(default=None, discriminator='py_type'),
        ]
    ] = None  #: Issuer repo.
    revoke_reason: t.Optional[str] = (
        None  #: Describes the reason for revocation, also indicating that the verification is no longer valid.
    )
    revoked_at: t.Optional[string_formats.DateTime] = None  #: Timestamp when the verification was revoked.
    revoked_by: t.Optional[string_formats.Did] = None  #: The user who revoked this verification.
    subject_profile: t.Optional[te.Annotated[t.Union['base.UnknownUnionModel'], Field(default=None)]] = (
        None  #: Subject profile.
    )
    subject_repo: t.Optional[
        te.Annotated[
            t.Union[
                'models.ToolsOzoneModerationDefs.RepoViewDetail', 'models.ToolsOzoneModerationDefs.RepoViewNotFound'
            ],
            Field(default=None, discriminator='py_type'),
        ]
    ] = None  #: Subject repo.

    py_type: t.Literal['tools.ozone.verification.defs#verificationView'] = Field(
        default='tools.ozone.verification.defs#verificationView', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te

from atproto_client.models import base, string_formats


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`com.atproto.sync.getBlob`."""

    cid: string_formats.Cid  #: The CID of the blob to fetch.
    did: string_formats.Did  #: The DID of the account.


class ParamsDict(t.TypedDict):
    cid: string_formats.Cid  #: The CID of the blob to fetch.
    did: string_formats.Did  #: The DID of the account.


#: Response raw data type.
Response: te.TypeAlias = bytes



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Event(base.ModelBase):
    """Definition model for :obj:`tools.ozone.safelink.defs`. An event for URL safety decisions."""

    action: 'models.ToolsOzoneSafelinkDefs.ActionType'  #: Action.
    created_at: string_formats.DateTime  #: Created at.
    created_by: string_formats.Did  #: DID of the user who created this rule.
    event_type: 'models.ToolsOzoneSafelinkDefs.EventType'  #: Event type.
    id: int  #: Auto-incrementing row ID.
    pattern: 'models.ToolsOzoneSafelinkDefs.PatternType'  #: Pattern.
    reason: 'models.ToolsOzoneSafelinkDefs.ReasonType'  #: Reason.
    url: str  #: The URL that this rule applies to.
    comment: t.Optional[str] = None  #: Optional comment about the decision.

    py_type: t.Literal['tools.ozone.safelink.defs#event'] = Field(
        default='tools.ozone.safelink.defs#event', alias='$type', frozen=True
    )


EventType = t.Union[t.Literal['addRule'], t.Literal['updateRule'], t.Literal['removeRule'], str]  #: Event type

PatternType = t.Union[t.Literal['domain'], t.Literal['url'], str]  #: Pattern type

ActionType = t.Union[t.Literal['block'], t.Literal['warn'], t.Literal['whitelist'], str]  #: Action type

ReasonType = t.Union[
    t.Literal['csam'], t.Literal['spam'], t.Literal['phishing'], t.Literal['none'], str
]  #: Reason type


class UrlRule(base.ModelBase):
    """Definition model for :obj:`tools.ozone.safelink.defs`. Input for creating a URL safety rule."""

    action: 'models.ToolsOzoneSafelinkDefs.ActionType'  #: Action.
    created_at: string_formats.DateTime  #: Timestamp when the rule was created.
    created_by: string_formats.Did  #: DID of the user added the rule.
    pattern: 'models.ToolsOzoneSafelinkDefs.PatternType'  #: Pattern.
    reason: 'models.ToolsOzoneSafelinkDefs.ReasonType'  #: Reason.
    updated_at: string_formats.DateTime  #: Timestamp when the rule was last updated.
    url: str  #: The URL or domain to apply the rule to.
    comment: t.Optional[str] = None  #: Optional comment about the decision.

    py_type: t.Literal['tools.ozone.safelink.defs#urlRule'] = Field(
        default='tools.ozone.safelink.defs#urlRule', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`tools.ozone.safelink.removeRule`."""

    pattern: 'models.ToolsOzoneSafelinkDefs.PatternType'  #: Pattern.
    url: str  #: The URL or domain to remove the rule for.
    comment: t.Optional[str] = None  #: Optional comment about why the rule is being removed.
    created_by: t.Optional[string_formats.Did] = (
        None  #: Optional DID of the user. Only respected when using admin auth.
    )


class DataDict(t.TypedDict):
    pattern: 'models.ToolsOzoneSafelinkDefs.PatternType'  #: Pattern.
    url: str  #: The URL or domain to remove the rule for.
    comment: te.NotRequired[t.Optional[str]]  #: Optional comment about why the rule is being removed.
    created_by: te.NotRequired[
        t.Optional[string_formats.Did]
    ]  #: Optional DID of the user. Only respected when using admin auth.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Response(base.ResponseModelBase):
    """Output data model for :obj:`app.bsky.unspecced.getConfig`."""

    check_email_confirmed: t.Optional[bool] = None  #: Check email confirmed.
    live_now: t.Optional[t.List['models.AppBskyUnspeccedGetConfig.LiveNowConfig']] = None  #: Live now.


class LiveNowConfig(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.getConfig`."""

    did: string_formats.Did  #: Did.
    domains: t.List[str]  #: Domains.

    py_type: t.Literal['app.bsky.unspecced.getConfig#liveNowConfig'] = Field(
        default='app.bsky.unspecced.getConfig#liveNowConfig', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class SkeletonSearchPost(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.defs`."""

    uri: string_formats.AtUri  #: Uri.

    py_type: t.Literal['app.bsky.unspecced.defs#skeletonSearchPost'] = Field(
        default='app.bsky.unspecced.defs#skeletonSearchPost', alias='$type', frozen=True
    )


class SkeletonSearchActor(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.defs`."""

    did: string_formats.Did  #: Did.

    py_type: t.Literal['app.bsky.unspecced.defs#skeletonSearchActor'] = Field(
        default='app.bsky.unspecced.defs#skeletonSearchActor', alias='$type', frozen=True
    )


class SkeletonSearchStarterPack(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.defs`."""

    uri: string_formats.AtUri  #: Uri.

    py_type: t.Literal['app.bsky.unspecced.defs#skeletonSearchStarterPack'] = Field(
        default='app.bsky.unspecced.defs#skeletonSearchStarterPack', alias='$type', frozen=True
    )


class TrendingTopic(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.defs`."""

    link: str  #: Link.
    topic: str  #: Topic.
    description: t.Optional[str] = None  #: Description.
    display_name: t.Optional[str] = None  #: Display name.

    py_type: t.Literal['app.bsky.unspecced.defs#trendingTopic'] = Field(
        default='app.bsky.unspecced.defs#trendingTopic', alias='$type', frozen=True
    )


class SkeletonTrend(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.defs`."""

    dids: t.List[string_formats.Did]  #: Dids.
    display_name: str  #: Display name.
    link: str  #: Link.
    post_count: int  #: Post count.
    started_at: string_formats.DateTime  #: Started at.
    topic: str  #: Topic.
    category: t.Optional[str] = None  #: Category.
    status: t.Optional[t.Union[t.Literal['hot'], str]] = None  #: Status.

    py_type: t.Literal['app.bsky.unspecced.defs#skeletonTrend'] = Field(
        default='app.bsky.unspecced.defs#skeletonTrend', alias='$type', frozen=True
    )


class TrendView(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.defs`."""

    actors: t.List['models.AppBskyActorDefs.ProfileViewBasic']  #: Actors.
    display_name: str  #: Display name.
    link: str  #: Link.
    post_count: int  #: Post count.
    started_at: string_formats.DateTime  #: Started at.
    topic: str  #: Topic.
    category: t.Optional[str] = None  #: Category.
    status: t.Optional[t.Union[t.Literal['hot'], str]] = None  #: Status.

    py_type: t.Literal['app.bsky.unspecced.defs#trendView'] = Field(
        default='app.bsky.unspecced.defs#trendView', alias='$type', frozen=True
    )


class ThreadItemPost(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.defs`."""

    hidden_by_threadgate: bool  #: The threadgate created by the author indicates this post as a reply to be hidden for everyone consuming the thread.
    more_parents: bool  #: This post has more parents that were not present in the response. This is just a boolean, without the number of parents.
    more_replies: int  #: This post has more replies that were not present in the response. This is a numeric value, which is best-effort and might not be accurate.
    muted_by_viewer: bool  #: This is by an account muted by the viewer requesting it.
    op_thread: bool  #: This post is part of a contiguous thread by the OP from the thread root. Many different OP threads can happen in the same thread.
    post: 'models.AppBskyFeedDefs.PostView'  #: Post.

    py_type: t.Literal['app.bsky.unspecced.defs#threadItemPost'] = Field(
        default='app.bsky.unspecced.defs#threadItemPost', alias='$type', frozen=True
    )


class ThreadItemNoUnauthenticated(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.defs`."""

    py_type: t.Literal['app.bsky.unspecced.defs#threadItemNoUnauthenticated'] = Field(
        default='app.bsky.unspecced.defs#threadItemNoUnauthenticated', alias='$type', frozen=True
    )


class ThreadItemNotFound(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.defs`."""

    py_type: t.Literal['app.bsky.unspecced.defs#threadItemNotFound'] = Field(
        default='app.bsky.unspecced.defs#threadItemNotFound', alias='$type', frozen=True
    )


class ThreadItemBlocked(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.defs`."""

    author: 'models.AppBskyFeedDefs.BlockedAuthor'  #: Author.

    py_type: t.Literal['app.bsky.unspecced.defs#threadItemBlocked'] = Field(
        default='app.bsky.unspecced.defs#threadItemBlocked', alias='$type', frozen=True
    )


class AgeAssuranceState(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.defs`. The computed state of the age assurance process, returned to the user in question on certain authenticated requests."""

    status: t.Union[
        t.Literal['unknown'], t.Literal['pending'], t.Literal['assured'], t.Literal['blocked'], str
    ]  #: The status of the age assurance process.
    last_initiated_at: t.Optional[string_formats.DateTime] = None  #: The timestamp when this state was last updated.

    py_type: t.Literal['app.bsky.unspecced.defs#ageAssuranceState'] = Field(
        default='app.bsky.unspecced.defs#ageAssuranceState', alias='$type', frozen=True
    )


class AgeAssuranceEvent(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.defs`. Object used to store age assurance data in stash."""

    attempt_id: str  #: The unique identifier for this instance of the age assurance flow, in UUID format.
    created_at: string_formats.DateTime  #: The date and time of this write operation.
    status: t.Union[
        t.Literal['unknown'], t.Literal['pending'], t.Literal['assured'], str
    ]  #: The status of the age assurance process.
    complete_ip: t.Optional[str] = None  #: The IP address used when completing the AA flow.
    complete_ua: t.Optional[str] = None  #: The user agent used when completing the AA flow.
    email: t.Optional[str] = None  #: The email used for AA.
    init_ip: t.Optional[str] = None  #: The IP address used when initiating the AA flow.
    init_ua: t.Optional[str] = None  #: The user agent used when initiating the AA flow.

    py_type: t.Literal['app.bsky.unspecced.defs#ageAssuranceEvent'] = Field(
        default='app.bsky.unspecced.defs#ageAssuranceEvent', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class RecordDeleted(base.ModelBase):
    """Definition model for :obj:`app.bsky.notification.defs`."""

    py_type: t.Literal['app.bsky.notification.defs#recordDeleted'] = Field(
        default='app.bsky.notification.defs#recordDeleted', alias='$type', frozen=True
    )


class ChatPreference(base.ModelBase):
    """Definition model for :obj:`app.bsky.notification.defs`."""

    include: t.Union[t.Literal['all'], t.Literal['accepted'], str]  #: Include.
    push: bool  #: Push.

    py_type: t.Literal['app.bsky.notification.defs#chatPreference'] = Field(
        default='app.bsky.notification.defs#chatPreference', alias='$type', frozen=True
    )


class FilterablePreference(base.ModelBase):
    """Definition model for :obj:`app.bsky.notification.defs`."""

    include: t.Union[t.Literal['all'], t.Literal['follows'], str]  #: Include.
    list: bool  #: List.
    push: bool  #: Push.

    py_type: t.Literal['app.bsky.notification.defs#filterablePreference'] = Field(
        default='app.bsky.notification.defs#filterablePreference', alias='$type', frozen=True
    )


class Preference(base.ModelBase):
    """Definition model for :obj:`app.bsky.notification.defs`."""

    list: bool  #: List.
    push: bool  #: Push.

    py_type: t.Literal['app.bsky.notification.defs#preference'] = Field(
        default='app.bsky.notification.defs#preference', alias='$type', frozen=True
    )


class Preferences(base.ModelBase):
    """Definition model for :obj:`app.bsky.notification.defs`."""

    chat: 'models.AppBskyNotificationDefs.ChatPreference'  #: Chat.
    follow: 'models.AppBskyNotificationDefs.FilterablePreference'  #: Follow.
    like: 'models.AppBskyNotificationDefs.FilterablePreference'  #: Like.
    like_via_repost: 'models.AppBskyNotificationDefs.FilterablePreference'  #: Like via repost.
    mention: 'models.AppBskyNotificationDefs.FilterablePreference'  #: Mention.
    quote: 'models.AppBskyNotificationDefs.FilterablePreference'  #: Quote.
    reply: 'models.AppBskyNotificationDefs.FilterablePreference'  #: Reply.
    repost: 'models.AppBskyNotificationDefs.FilterablePreference'  #: Repost.
    repost_via_repost: 'models.AppBskyNotificationDefs.FilterablePreference'  #: Repost via repost.
    starterpack_joined: 'models.AppBskyNotificationDefs.Preference'  #: Starterpack joined.
    subscribed_post: 'models.AppBskyNotificationDefs.Preference'  #: Subscribed post.
    unverified: 'models.AppBskyNotificationDefs.Preference'  #: Unverified.
    verified: 'models.AppBskyNotificationDefs.Preference'  #: Verified.

    py_type: t.Literal['app.bsky.notification.defs#preferences'] = Field(
        default='app.bsky.notification.defs#preferences', alias='$type', frozen=True
    )


class ActivitySubscription(base.ModelBase):
    """Definition model for :obj:`app.bsky.notification.defs`."""

    post: bool  #: Post.
    reply: bool  #: Reply.

    py_type: t.Literal['app.bsky.notification.defs#activitySubscription'] = Field(
        default='app.bsky.notification.defs#activitySubscription', alias='$type', frozen=True
    )


class SubjectActivitySubscription(base.ModelBase):
    """Definition model for :obj:`app.bsky.notification.defs`. Object used to store activity subscription data in stash."""

    activity_subscription: 'models.AppBskyNotificationDefs.ActivitySubscription'  #: Activity subscription.
    subject: string_formats.Did  #: Subject.

    py_type: t.Literal['app.bsky.notification.defs#subjectActivitySubscription'] = Field(
        default='app.bsky.notification.defs#subjectActivitySubscription', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`com.atproto.server.getAccountInviteCodes`."""

    create_available: t.Optional[bool] = (
        True  #: Controls whether any new 'earned' but not 'created' invites should be created.
    )
    include_used: t.Optional[bool] = True  #: Include used.


class ParamsDict(t.TypedDict):
    create_available: te.NotRequired[
        t.Optional[bool]
    ]  #: Controls whether any new 'earned' but not 'created' invites should be created.
    include_used: te.NotRequired[t.Optional[bool]]  #: Include used.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`com.atproto.server.getAccountInviteCodes`."""

    codes: t.List['models.ComAtprotoServerDefs.InviteCode']  #: Codes.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class FeedItem(base.ModelBase):
    """Definition model for :obj:`app.bsky.graph.starterpack`."""

    uri: string_formats.AtUri  #: Uri.

    py_type: t.Literal['app.bsky.graph.starterpack#feedItem'] = Field(
        default='app.bsky.graph.starterpack#feedItem', alias='$type', frozen=True
    )


class Record(base.RecordModelBase):
    """Record model for :obj:`app.bsky.graph.starterpack`."""

    created_at: string_formats.DateTime  #: Created at.
    list: string_formats.AtUri  #: Reference (AT-URI) to the list record.
    name: str = Field(min_length=1, max_length=500)  #: Display name for starter pack; can not be empty.
    description: te.Annotated[t.Optional[str], Field(max_length=3000)] = None  #: Description.
    description_facets: t.Optional[t.List['models.AppBskyRichtextFacet.Main']] = None  #: Description facets.
    feeds: te.Annotated[t.Optional[t.List['models.AppBskyGraphStarterpack.FeedItem']], Field(max_length=3)] = (
        None  #: Feeds.
    )

    py_type: t.Literal['app.bsky.graph.starterpack'] = Field(
        default='app.bsky.graph.starterpack', alias='$type', frozen=True
    )


class GetRecordResponse(base.SugarResponseModelBase):
    """Get record response for :obj:`models.AppBskyGraphStarterpack.Record`."""

    uri: str  #: The URI of the record.
    value: 'models.AppBskyGraphStarterpack.Record'  #: The record.
    cid: t.Optional[str] = None  #: The CID of the record.


class ListRecordsResponse(base.SugarResponseModelBase):
    """List records response for :obj:`models.AppBskyGraphStarterpack.Record`."""

    records: t.Dict[str, 'models.AppBskyGraphStarterpack.Record']  #: Map of URIs to records.
    cursor: t.Optional[str] = None  #: Next page cursor.


class CreateRecordResponse(base.SugarResponseModelBase):
    """Create record response for :obj:`models.AppBskyGraphStarterpack.Record`."""

    uri: str  #: The URI of the record.
    cid: str  #: The CID of the record.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

from pydantic import Field

from atproto_client.models import base, string_formats


class CommitMeta(base.ModelBase):
    """Definition model for :obj:`com.atproto.repo.defs`."""

    cid: string_formats.Cid  #: Cid.
    rev: string_formats.Tid  #: Rev.

    py_type: t.Literal['com.atproto.repo.defs#commitMeta'] = Field(
        default='com.atproto.repo.defs#commitMeta', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`com.atproto.temp.checkHandleAvailability`."""

    handle: (
        string_formats.Handle
    )  #: Tentative handle. Will be checked for availability or used to build handle suggestions.
    birth_date: t.Optional[string_formats.DateTime] = (
        None  #: User-provided birth date. Might be used to build handle suggestions.
    )
    email: t.Optional[str] = None  #: User-provided email. Might be used to build handle suggestions.


class ParamsDict(t.TypedDict):
    handle: (
        string_formats.Handle
    )  #: Tentative handle. Will be checked for availability or used to build handle suggestions.
    birth_date: te.NotRequired[
        t.Optional[string_formats.DateTime]
    ]  #: User-provided birth date. Might be used to build handle suggestions.
    email: te.NotRequired[t.Optional[str]]  #: User-provided email. Might be used to build handle suggestions.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`com.atproto.temp.checkHandleAvailability`."""

    handle: string_formats.Handle  #: Echo of the input handle.
    result: te.Annotated[
        t.Union[
            'models.ComAtprotoTempCheckHandleAvailability.ResultAvailable',
            'models.ComAtprotoTempCheckHandleAvailability.ResultUnavailable',
        ],
        Field(discriminator='py_type'),
    ]  #: Result.


class ResultAvailable(base.ModelBase):
    """Definition model for :obj:`com.atproto.temp.checkHandleAvailability`. Indicates the provided handle is available."""

    py_type: t.Literal['com.atproto.temp.checkHandleAvailability#resultAvailable'] = Field(
        default='com.atproto.temp.checkHandleAvailability#resultAvailable', alias='$type', frozen=True
    )


class ResultUnavailable(base.ModelBase):
    """Definition model for :obj:`com.atproto.temp.checkHandleAvailability`. Indicates the provided handle is unavailable and gives suggestions of available handles."""

    suggestions: t.List[
        'models.ComAtprotoTempCheckHandleAvailability.Suggestion'
    ]  #: List of suggested handles based on the provided inputs.

    py_type: t.Literal['com.atproto.temp.checkHandleAvailability#resultUnavailable'] = Field(
        default='com.atproto.temp.checkHandleAvailability#resultUnavailable', alias='$type', frozen=True
    )


class Suggestion(base.ModelBase):
    """Definition model for :obj:`com.atproto.temp.checkHandleAvailability`."""

    handle: string_formats.Handle  #: Handle.
    method: (
        str  #: Method used to build this suggestion. Should be considered opaque to clients. Can be used for metrics.
    )

    py_type: t.Literal['com.atproto.temp.checkHandleAvailability#suggestion'] = Field(
        default='com.atproto.temp.checkHandleAvailability#suggestion', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`tools.ozone.verification.listVerifications`."""

    created_after: t.Optional[string_formats.DateTime] = None  #: Filter to verifications created after this timestamp.
    created_before: t.Optional[string_formats.DateTime] = (
        None  #: Filter to verifications created before this timestamp.
    )
    cursor: t.Optional[str] = None  #: Pagination cursor.
    is_revoked: t.Optional[bool] = None  #: Filter to verifications that are revoked or not. By default, includes both.
    issuers: te.Annotated[t.Optional[t.List[string_formats.Did]], Field(max_length=100)] = (
        None  #: Filter to verifications from specific issuers.
    )
    limit: te.Annotated[t.Optional[int], Field(ge=1, le=100)] = None  #: Maximum number of results to return.
    sort_direction: t.Optional[t.Union[t.Literal['asc'], t.Literal['desc']]] = (
        'desc'  #: Sort direction for creation date.
    )
    subjects: te.Annotated[t.Optional[t.List[string_formats.Did]], Field(max_length=100)] = (
        None  #: Filter to specific verified DIDs.
    )


class ParamsDict(t.TypedDict):
    created_after: te.NotRequired[
        t.Optional[string_formats.DateTime]
    ]  #: Filter to verifications created after this timestamp.
    created_before: te.NotRequired[
        t.Optional[string_formats.DateTime]
    ]  #: Filter to verifications created before this timestamp.
    cursor: te.NotRequired[t.Optional[str]]  #: Pagination cursor.
    is_revoked: te.NotRequired[
        t.Optional[bool]
    ]  #: Filter to verifications that are revoked or not. By default, includes both.
    issuers: te.NotRequired[t.Optional[t.List[string_formats.Did]]]  #: Filter to verifications from specific issuers.
    limit: te.NotRequired[t.Optional[int]]  #: Maximum number of results to return.
    sort_direction: te.NotRequired[
        t.Optional[t.Union[t.Literal['asc'], t.Literal['desc']]]
    ]  #: Sort direction for creation date.
    subjects: te.NotRequired[t.Optional[t.List[string_formats.Did]]]  #: Filter to specific verified DIDs.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`tools.ozone.verification.listVerifications`."""

    verifications: t.List['models.ToolsOzoneVerificationDefs.VerificationView']  #: Verifications.
    cursor: t.Optional[str] = None  #: Cursor.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`app.bsky.unspecced.getTrendingTopics`."""

    limit: te.Annotated[t.Optional[int], Field(ge=1, le=25)] = None  #: Limit.
    viewer: t.Optional[string_formats.Did] = (
        None  #: DID of the account making the request (not included for public/unauthenticated queries). Used to boost followed accounts in ranking.
    )


class ParamsDict(t.TypedDict):
    limit: te.NotRequired[t.Optional[int]]  #: Limit.
    viewer: te.NotRequired[
        t.Optional[string_formats.Did]
    ]  #: DID of the account making the request (not included for public/unauthenticated queries). Used to boost followed accounts in ranking.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`app.bsky.unspecced.getTrendingTopics`."""

    suggested: t.List['models.AppBskyUnspeccedDefs.TrendingTopic']  #: Suggested.
    topics: t.List['models.AppBskyUnspeccedDefs.TrendingTopic']  #: Topics.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Bookmark(base.ModelBase):
    """Definition model for :obj:`app.bsky.bookmark.defs`. Object used to store bookmark data in stash."""

    subject: 'models.ComAtprotoRepoStrongRef.Main'  #: A strong ref to the record to be bookmarked. Currently, only `app.bsky.feed.post` records are supported.

    py_type: t.Literal['app.bsky.bookmark.defs#bookmark'] = Field(
        default='app.bsky.bookmark.defs#bookmark', alias='$type', frozen=True
    )


class BookmarkView(base.ModelBase):
    """Definition model for :obj:`app.bsky.bookmark.defs`."""

    item: te.Annotated[
        t.Union[
            'models.AppBskyFeedDefs.BlockedPost',
            'models.AppBskyFeedDefs.NotFoundPost',
            'models.AppBskyFeedDefs.PostView',
        ],
        Field(discriminator='py_type'),
    ]  #: Item.
    subject: 'models.ComAtprotoRepoStrongRef.Main'  #: A strong ref to the bookmarked record.
    created_at: t.Optional[string_formats.DateTime] = None  #: Created at.

    py_type: t.Literal['app.bsky.bookmark.defs#bookmarkView'] = Field(
        default='app.bsky.bookmark.defs#bookmarkView', alias='$type', frozen=True
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client.models.unknown_type import UnknownType
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`com.atproto.server.createSession`."""

    identifier: str  #: Handle or other identifier supported by the server for the authenticating user.
    password: str  #: Password.
    allow_takendown: t.Optional[bool] = (
        None  #: When true, instead of throwing error for takendown accounts, a valid response with a narrow scoped token will be returned.
    )
    auth_factor_token: t.Optional[str] = None  #: Auth factor token.


class DataDict(t.TypedDict):
    identifier: str  #: Handle or other identifier supported by the server for the authenticating user.
    password: str  #: Password.
    allow_takendown: te.NotRequired[
        t.Optional[bool]
    ]  #: When true, instead of throwing error for takendown accounts, a valid response with a narrow scoped token will be returned.
    auth_factor_token: te.NotRequired[t.Optional[str]]  #: Auth factor token.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`com.atproto.server.createSession`."""

    access_jwt: str  #: Access jwt.
    did: string_formats.Did  #: Did.
    handle: string_formats.Handle  #: Handle.
    refresh_jwt: str  #: Refresh jwt.
    active: t.Optional[bool] = None  #: Active.
    did_doc: t.Optional['UnknownType'] = None  #: Did doc.
    email: t.Optional[str] = None  #: Email.
    email_auth_factor: t.Optional[bool] = None  #: Email auth factor.
    email_confirmed: t.Optional[bool] = None  #: Email confirmed.
    status: t.Optional[t.Union[t.Literal['takendown'], t.Literal['suspended'], t.Literal['deactivated'], str]] = (
        None  #: If active=false, this optional field indicates a possible reason for why the account is not active. If active=false and no status is supplied, then the host makes no claim for why the repository is no longer being hosted.
    )



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Data(base.DataModelBase):
    """Input data model for :obj:`tools.ozone.safelink.queryEvents`."""

    cursor: t.Optional[str] = None  #: Cursor for pagination.
    limit: te.Annotated[t.Optional[int], Field(ge=1, le=100)] = None  #: Maximum number of results to return.
    pattern_type: t.Optional[str] = None  #: Filter by pattern type.
    sort_direction: t.Optional[t.Union[t.Literal['asc'], t.Literal['desc'], str]] = 'desc'  #: Sort direction.
    urls: t.Optional[t.List[str]] = None  #: Filter by specific URLs or domains.


class DataDict(t.TypedDict):
    cursor: te.NotRequired[t.Optional[str]]  #: Cursor for pagination.
    limit: te.NotRequired[t.Optional[int]]  #: Maximum number of results to return.
    pattern_type: te.NotRequired[t.Optional[str]]  #: Filter by pattern type.
    sort_direction: te.NotRequired[t.Optional[t.Union[t.Literal['asc'], t.Literal['desc'], str]]]  #: Sort direction.
    urls: te.NotRequired[t.Optional[t.List[str]]]  #: Filter by specific URLs or domains.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`tools.ozone.safelink.queryEvents`."""

    events: t.List['models.ToolsOzoneSafelinkDefs.Event']  #: Events.
    cursor: t.Optional[str] = None  #: Next cursor for pagination. Only present if there are more results.



##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2024 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


import typing as t

import typing_extensions as te
from pydantic import Field

from atproto_client.models import string_formats

if t.TYPE_CHECKING:
    from atproto_client import models
from atproto_client.models import base


class Params(base.ParamsModelBase):
    """Parameters model for :obj:`app.bsky.unspecced.getPostThreadV2`."""

    anchor: string_formats.AtUri  #: Reference (AT-URI) to post record. This is the anchor post, and the thread will be built around it. It can be any post in the tree, not necessarily a root post.
    above: t.Optional[bool] = True  #: Whether to include parents above the anchor.
    below: te.Annotated[t.Optional[int], Field(ge=0, le=20)] = (
        None  #: How many levels of replies to include below the anchor.
    )
    branching_factor: te.Annotated[t.Optional[int], Field(ge=0, le=100)] = (
        None  #: Maximum of replies to include at each level of the thread, except for the direct replies to the anchor, which are (NOTE: currently, during unspecced phase) all returned (NOTE: later they might be paginated).
    )
    prioritize_followed_users: t.Optional[bool] = (
        False  #: Whether to prioritize posts from followed users. It only has effect when the user is authenticated.
    )
    sort: t.Optional[t.Union[t.Literal['newest'], t.Literal['oldest'], t.Literal['top'], str]] = (
        'oldest'  #: Sorting for the thread replies.
    )


class ParamsDict(t.TypedDict):
    anchor: string_formats.AtUri  #: Reference (AT-URI) to post record. This is the anchor post, and the thread will be built around it. It can be any post in the tree, not necessarily a root post.
    above: te.NotRequired[t.Optional[bool]]  #: Whether to include parents above the anchor.
    below: te.NotRequired[t.Optional[int]]  #: How many levels of replies to include below the anchor.
    branching_factor: te.NotRequired[
        t.Optional[int]
    ]  #: Maximum of replies to include at each level of the thread, except for the direct replies to the anchor, which are (NOTE: currently, during unspecced phase) all returned (NOTE: later they might be paginated).
    prioritize_followed_users: te.NotRequired[
        t.Optional[bool]
    ]  #: Whether to prioritize posts from followed users. It only has effect when the user is authenticated.
    sort: te.NotRequired[
        t.Optional[t.Union[t.Literal['newest'], t.Literal['oldest'], t.Literal['top'], str]]
    ]  #: Sorting for the thread replies.


class Response(base.ResponseModelBase):
    """Output data model for :obj:`app.bsky.unspecced.getPostThreadV2`."""

    has_other_replies: bool  #: Whether this thread has additional replies. If true, a call can be made to the `getPostThreadOtherV2` endpoint to retrieve them.
    thread: t.List[
        'models.AppBskyUnspeccedGetPostThreadV2.ThreadItem'
    ]  #: A flat list of thread items. The depth of each item is indicated by the depth property inside the item.
    threadgate: t.Optional['models.AppBskyFeedDefs.ThreadgateView'] = None  #: Threadgate.


class ThreadItem(base.ModelBase):
    """Definition model for :obj:`app.bsky.unspecced.getPostThreadV2`."""

    depth: int  #: The nesting level of this item in the thread. Depth 0 means the anchor item. Items above have negative depths, items below have positive depths.
    uri: string_formats.AtUri  #: Uri.
    value: te.Annotated[
        t.Union[
            'models.AppBskyUnspeccedDefs.ThreadItemPost',
            'models.AppBskyUnspeccedDefs.ThreadItemNoUnauthenticated',
            'models.AppBskyUnspeccedDefs.ThreadItemNotFound',
            'models.AppBskyUnspeccedDefs.ThreadItemBlocked',
        ],
        Field(discriminator='py_type'),
    ]  #: Value.

    py_type: t.Literal['app.bsky.unspecced.getPostThreadV2#threadItem'] = Field(
        default='app.bsky.unspecced.getPostThreadV2#threadItem', alias='$type', frozen=True
    )
